@@ -1715,9 +1715,14 @@ class SaleLine(TaxableMixin, sequence_ordered(), ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return ['OR',
-            ('sale.rec_name',) + tuple(clause[1:]),
-            ('product.rec_name',) + tuple(clause[1:]),
+        _, operator, value = clause
+        if operator.startswith('!') or operator.startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
+        return [bool_op,
+            ('sale.rec_name', *clause[1:]),
+            ('product.rec_name', *clause[1:]),
             ]
 
     @classmethod
